Suivez la fréquence à laquelle les personnes, les entreprises ou les lieux apparaissent ensemble au fil du temps
Suivez la fréquence à laquelle les personnes, les entreprises ou les lieux apparaissent ensemble au fil du temps. Indiquez si la couverture est positive, négative ou neutre, et filtrez par source
Paramètres d'entrée
| Paramètre | Description | Type | Valeur par défaut | Requis |
|---|---|---|---|---|
| entity.id | Plusieurs identifiants d'entité, séparés par des virgules. | string | Oui | |
| published_at.start | Date de début pour la période de temps. | string | Oui | |
| published_at.end | Date de fin pour la période. | string | Oui | |
| sort.by | Trier par score de sentiment. | string | Oui | |
| sort.order | Ordre décroissant. | string | Oui | |
| is_duplicate | Exclure les doublons. | integer | 0 | Oui |
| api_key | Votre clé API | string | Oui | |
| per_page | Nombre maximum d'articles à récupérer | integer | 50 | Non |
Exemples de flux de travail
Découvrez quelles personnes, organisations et lieux apparaissent ensemble dans les articles :
curl -X GET "https://api.apitube.io/v1/news/everything?entity.id=1278268,1282301&published_at.start=2023-01-01&published_at.end=2023-12-31&sort.by=sentiment.overall.score&sort.order=desc&api_key=YOUR_API_KEY"
Suivez les mentions d'une personne, d'une organisation ou d'un lieu au fil du temps :
curl -X GET "https://api.apitube.io/v1/news/everything?entity.id=1278268&published_at.start=2022-01-01&published_at.end=2023-12-31&per_page=100&sort.by=published_at&sort.order=asc&api_key=YOUR_API_KEY"
Découvrez quelles personnes, organisations et lieux sont mentionnés ensemble :
curl -X GET "https://api.apitube.io/v1/news/everything?entity.id=1278268&organization.name=Tesla&published_at.start=2023-01-01&published_at.end=2023-12-31&sort.by=published_at&api_key=YOUR_API_KEY"
Voyez comment une personne, une organisation ou un lieu affecte la positivité, la négativité ou la neutralité de la couverture du marché :
curl -X GET "https://api.apitube.io/v1/news/everything?entity.id=1278268,1282301&category.id=medtop:04000000&sentiment.overall.score.min=0.7&published_at.start=2023-01-01&sort.by=sentiment.overall.score&sort.order=desc&api_key=YOUR_API_KEY"
Exemples connexes
- Trouvez avec quelles organisations une personne est mentionnée
- Analyse de la réputation de la marque
- Suivez vos concurrents
- Filtrer les articles mentionnant des personnes
- Triez par score d'engagement
Recette pour cURL
curl --location --globoff --request POST 'https://api.apitube.io/v1/news/everything?entity.id=1278268%2C1282301&published_at.start=2023-01-01&published_at.end=2023-12-31&sort.by=sentiment.overall.score&sort.order=desc&is_duplicate=0&api_key=YOUR_API_KEY&per_page=50' \
--header 'Content-Type: application/json'
Recette pour Python
import requests
url = "https://api.apitube.io/v1/news/everything"
querystring = {
"entity.id": "1278268,1282301",
"published_at.start": "2023-01-01",
"published_at.end": "2023-12-31",
"sort.by": "sentiment.overall.score",
"sort.order": "desc",
"is_duplicate": 0,
"api_key": "YOUR_API_KEY",
"per_page": 50
}
response = requests.request("GET", url, params=querystring)
print(response.text)
Recette pour Javascript
import axios from "axios"
const options = {
method: 'GET',
url: 'https://api.apitube.io/v1/news/everything',
params: {
"entity.id": "1278268,1282301",
"published_at.start": "2023-01-01",
"published_at.end": "2023-12-31",
"sort.by": "sentiment.overall.score",
"sort.order": "desc",
"is_duplicate": 0,
"api_key": "YOUR_API_KEY",
"per_page": 50
}};
axios.request(options).then(function (response) {
console.log(response.data);
}).catch(function (error) {
console.error(error);
});
Recette pour PHP
require 'vendor/autoload.php';
use GuzzleHttp\Client;
$client = new Client();
$response = $client->request('GET', 'https://api.apitube.io/v1/news/everything', [
'query' => [
'entity.id' => '1278268,1282301',
'published_at.start' => '2023-01-01',
'published_at.end' => '2023-12-31',
'sort.by' => 'sentiment.overall.score',
'sort.order' => 'desc',
'is_duplicate' => 0,
'api_key' => 'YOUR_API_KEY',
'per_page' => 50,
],
]);
echo $response->getBody();
Recette pour Java
OkHttpClient client = new OkHttpClient().newBuilder().build();
MediaType mediaType = MediaType.parse("application/json");
RequestBody body = RequestBody.create(mediaType, "");
Request request = new Request.Builder()
.url("https://api.apitube.io/v1/news/everything?entity.id=1278268%2C1282301&published_at.start=2023-01-01&published_at.end=2023-12-31&sort.by=sentiment.overall.score&sort.order=desc&is_duplicate=0&api_key=YOUR_API_KEY&per_page=50")
.method("POST", body)
.addHeader("Content-Type", "application/json")
.build();
Response response = client.newCall(request).execute();